=== added file 'bzrlib/_rio_py.py'
--- bzrlib/_rio_py.py	1970-01-01 00:00:00 +0000
+++ bzrlib/_rio_py.py	2009-05-14 11:00:33 +0000
@@ -0,0 +1,71 @@
+# Copyright (C) 2009 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+import re
+
+from bzrlib.rio import (
+    Stanza,
+    )
+
+_tag_re = re.compile(r'^[-a-zA-Z0-9_]+$')
+def _valid_tag(tag):
+    return bool(_tag_re.match(tag))
+
+
+def _read_stanza_utf8(line_iter):
+    unicode_iter = (line.decode('utf-8') for line in line_iter)
+    return _read_stanza_unicode(unicode_iter)
+
+
+def _read_stanza_unicode(unicode_iter):
+    stanza = Stanza()
+    tag = None
+    accum_value = None
+
+    # TODO: jam 20060922 This code should raise real errors rather than
+    #       using 'assert' to process user input, or raising ValueError
+    #       rather than a more specific error.
+    for line in unicode_iter:
+        if line is None or line == '':
+            break       # end of file
+        if line == '\n':
+            break       # end of stanza
+        real_l = line
+        if line[0] == '\t': # continues previous value
+            if tag is None:
+                raise ValueError('invalid continuation line %r' % real_l)
+            accum_value += '\n' + line[1:-1]
+        else: # new tag:value line
+            if tag is not None:
+                stanza.add(tag, accum_value)
+            try:
+                colon_index = line.index(': ')
+            except ValueError:
+                raise ValueError('tag/value separator not found in line %r'
+                                 % real_l)
+            tag = str(line[:colon_index])
+            if not _valid_tag(tag):
+                raise ValueError("invalid rio tag %r" % (tag,))
+            accum_value = line[colon_index+2:-1]
+
+    if tag is not None: # add last tag-value
+        stanza.add(tag, accum_value)
+        return stanza
+    else:     # didn't see any content
+        return None
+
+
+

=== added file 'bzrlib/_rio_pyx.pyx'
--- bzrlib/_rio_pyx.pyx	1970-01-01 00:00:00 +0000
+++ bzrlib/_rio_pyx.pyx	2009-05-14 11:00:33 +0000
@@ -0,0 +1,17 @@
+# Copyright (C) 2009 Canonical Ltd
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+
+

=== modified file 'bzrlib/rio.py'
--- bzrlib/rio.py	2009-03-23 14:59:43 +0000
+++ bzrlib/rio.py	2009-05-14 11:00:33 +0000
@@ -236,9 +236,9 @@
             d[tag] = value
         return d
 
-_tag_re = re.compile(r'^[-a-zA-Z0-9_]+$')
+
 def valid_tag(tag):
-    return bool(_tag_re.match(tag))
+    return _valid_tag(tag)
 
 
 def read_stanza(line_iter):
@@ -254,8 +254,7 @@
 
     The raw lines must be in utf-8 encoding.
     """
-    unicode_iter = (line.decode('utf-8') for line in line_iter)
-    return read_stanza_unicode(unicode_iter)
+    return _read_stanza_utf8(line_iter)
 
 
 def read_stanza_unicode(unicode_iter):
@@ -275,43 +274,7 @@
     :return: A Stanza object if there are any lines in the file.
         None otherwise
     """
-    stanza = Stanza()
-    tag = None
-    accum_value = None
-
-    # TODO: jam 20060922 This code should raise real errors rather than
-    #       using 'assert' to process user input, or raising ValueError
-    #       rather than a more specific error.
-
-    for line in unicode_iter:
-        if line is None or line == '':
-            break       # end of file
-        if line == '\n':
-            break       # end of stanza
-        real_l = line
-        if line[0] == '\t': # continues previous value
-            if tag is None:
-                raise ValueError('invalid continuation line %r' % real_l)
-            accum_value += '\n' + line[1:-1]
-        else: # new tag:value line
-            if tag is not None:
-                stanza.add(tag, accum_value)
-            try:
-                colon_index = line.index(': ')
-            except ValueError:
-                raise ValueError('tag/value separator not found in line %r'
-                                 % real_l)
-            tag = str(line[:colon_index])
-            if not valid_tag(tag):
-                raise ValueError("invalid rio tag %r" % (tag,))
-            accum_value = line[colon_index+2:-1]
-
-    if tag is not None: # add last tag-value
-        stanza.add(tag, accum_value)
-        return stanza
-    else:     # didn't see any content
-        return None
-
+    return _read_stanza_unicode(unicode_iter)
 
 def to_patch_lines(stanza, max_width=72):
     """Convert a stanza into RIO-Patch format lines.
@@ -399,3 +362,17 @@
     :return: a Stanza
     """
     return read_stanza(_patch_stanza_iter(line_iter))
+
+
+try:
+    from bzrlib._rio_pyx import (
+        _read_stanza_utf8,
+        _read_stanza_unicode,
+        _valid_tag,
+        )
+except ImportError:
+    from bzrlib._rio_py import (
+       _read_stanza_utf8,
+       _read_stanza_unicode,
+       _valid_tag,
+       )

